@@ -37,11 +37,7 @@
   #define bind_textdomain_codeset(domain,codeset)
 #endif
 
-struct KanaInputKey {
-    int code;
-    const char kana[6];
-};
-
+namespace ScimWnn {
 const KanaInputKey KanaInputTable[] = {
     {SCIM_KEY_kana_fullstop,        ""},
     {SCIM_KEY_kana_openingbracket,  ""},
@@ -112,7 +108,7 @@ const KanaInputKey KanaInputTable[] = {
 
     {0,""}
 };
-
+}
 
 KanaInput::KanaInput(ConfigPointer cfg) : PreEditor(cfg)
 {
@@ -169,7 +165,7 @@ bool KanaInput::inputEvent(const KeyEvent &key)
     }
     if ((((key.get_ascii_code() == '@') && (fakeKanaInput)) || (key.code == SCIM_KEY_voicedsound )) && (pos > 0)) {
         WideString vs1,vs2;
-        iconvert.convert(vs1,String("ƤȤϤҤդؤۤѤԤפڤ"));
+        iconvert.convert(vs1,String("ĤƤȤϤҤդؤۤѤԤפڤ"));
         iconvert.convert(vs2,String("¤ŤǤɤФӤ֤٤ܤФӤ֤٤"));
         for(unsigned int i = 0;i < vs1.length();i ++) {
             if (vs1[i] == text[pos - 1]) text = text.substr(0,pos - 1) + vs2[i] + text.substr(pos);
