@@ -34,6 +34,14 @@ using namespace scim;
 /**
 @author TAM(Teppei Tamra)
 */
+namespace ScimWnn {
+
+struct KanaInputKey {
+    int code;
+    const char kana[6];
+};
+
+
 class KanaInput : public PreEditor {
 public:
     KanaInput(ConfigPointer cfg);
@@ -47,5 +55,6 @@ public:
 protected:
     bool fakeKanaInput;
 };
+}
 
 #endif
