@@ -342,3 +342,12 @@ void PreEditor::setText(const WideString &t)
     text = t;
 }
 
+
+
+/*!
+    \fn PreEditor::getAttributeList()
+ */
+AttributeList PreEditor::getAttributeList()
+{
+    return(AttributeList());
+}
