@@ -27,6 +27,7 @@
 #include <scim.h>
 #include <scim_iconv.h>
 #include <scim_event.h>
+#include <scim_attribute.h>
 
 #define HIRA_START      0
 #define HIRA_END        1
@@ -50,6 +51,7 @@ using namespace scim;
 /**
 @author TAM(Teppei Tamra)
 */
+namespace ScimWnn {
 class PreEditorKeyEventList : public KeyEventList
 {
     // ꥹȤ˥٥Ȥɲäơcomp(KeyEvent)Ƚ̡
@@ -88,6 +90,7 @@ public:
     virtual void setText(const WideString &t);
     virtual void toWide();
     virtual void toHalf();
+    virtual AttributeList getAttributeList();
 
 protected:
     static WideString text;
@@ -98,5 +101,7 @@ protected:
     static map<ucs4_t,WideString> hKanaChars;
 
 };
+}
 
+using namespace ScimWnn;
 #endif
