@@ -570,6 +570,7 @@ bool Romkan::inputEvent(const KeyEvent &key)
         // ľ֤٤
         if ((key.code == SCIM_KEY_Return) ||
             (key.code == SCIM_KEY_Linefeed) ||
+            (key.code == SCIM_KEY_BackSpace) ||
             (key.code == SCIM_KEY_Tab)) return(false);
         insert(key.get_ascii_code());
         return(true);
@@ -587,3 +588,17 @@ String Romkan::getName()
 }
 
 
+
+
+/*!
+    \fn Romkan::getAttributeList()
+ */
+AttributeList Romkan::getAttributeList()
+{
+    AttributeList l;
+    if (buf.length()) {
+        Attribute a(pos - buf.length(),buf.length(),SCIM_ATTR_FOREGROUND,SCIM_RGB_COLOR(255,0,0));
+        l.push_back(a);
+    }
+    return(l);
+}
