@@ -36,6 +36,7 @@ using namespace scim;
 /**
 @author TAM(Teppei Tamra)
 */
+namespace ScimWnn {
 struct RomkanTableEntry {
     String key;
     WideString kana;
@@ -70,6 +71,7 @@ public:
     virtual String getName();
     virtual String getPropertyName() {return(String("Romkan"));};
     virtual void setText(const WideString &t);
+    virtual AttributeList getAttributeList();
 
 protected:
     WideString eval();
@@ -93,5 +95,5 @@ protected:
     String hookp;
     vector<RomkanKeyEventList> hookKey;
 };
-
+}
 #endif
