@@ -116,7 +116,7 @@ WideString WnnFactory::get_name () const
 
 WideString WnnFactory::get_authors () const
 {
-    return utf8_mbstowcs (String (_("(C) 2004 TAM(Teppei Tamra) <tam-t@par.odn.ne.jp>")));
+    return utf8_mbstowcs (String (_("(C)2004-2006 TAM(Teppei Tamra) <tam-t@par.odn.ne.jp>")));
 }
 
 WideString WnnFactory::get_credits () const
@@ -181,10 +181,12 @@ bool WnnKeyEventList::comp(const KeyEvent &k) {
 WnnInstance::WnnInstance (WnnFactory *factory, const String& encoding, int id)
     : IMEngineInstanceBase (factory, encoding, id)
 {
+    SCIM_DEBUG_IMENGINE(1) << "!!! WNNINSTANCE !!!\n";
     m_iconv.set_encoding ("EUC-JP");
     preeditors.push_back(new Romkan(_scim_config));
     preeditors.push_back(new KanaInput(_scim_config));
     m_preeditor = preeditors.at(0);
+    wnn = 0;
     init();
 }
 
@@ -193,7 +195,7 @@ WnnInstance::~WnnInstance()
     for(unsigned int i = 0;i < preeditors.size();i ++) {
         delete(preeditors.at(i));
     }
-    if (wnn.isConnected()) wnn.wnnDisconnect();
+    if (wnn->isConnected()) wnn->disconnect();
 }
 
 
@@ -208,24 +210,16 @@ void WnnInstance::init()
 
     // @todo if connected to jserver, should disconnect this.
 
-    host = _scim_config->read(String(SCIM_CONFIG_WNN_SERVER),String(SCIM_DEFAULT_WNN_SERVER));
-    rc = _scim_config->read(String(SCIM_CONFIG_WNN_RC),String(SCIM_DEFAULT_WNN_RC));
     alp = _scim_config->read(String(SCIM_CONFIG_WNN_ALP),SCIM_DEFAULT_WNN_ALP);
     mini_status = _scim_config->read(String(SCIM_CONFIG_WNN_MINISTATUS),SCIM_DEFAULT_WNN_MINISTATUS);
     numkeyselect = _scim_config->read(String(SCIM_CONFIG_WNN_NUMKEY_SELECT),SCIM_DEFAULT_WNN_NUMKEY_SELECT);
     yosoku = _scim_config->read(String(SCIM_CONFIG_WNN_YOSOKU),SCIM_DEFAULT_WNN_YOSOKU);
-    String t = _scim_config->read(String(SCIM_CONFIG_WNN_SERVERTYPE),String(SCIM_DEFAULT_WNN_SERVERTYPE));
-
-    if (t == "Wnn6") {
-        sType = Wnn6;
-    } else if (t == "Wnn7") {
-        sType = Wnn7;
-    } else if (t == "Wnn8") {
-        sType = Wnn8;
-    } else {
-        sType = Wnn4;
-    }
+    sType = _scim_config->read(String(SCIM_CONFIG_WNN_SERVERTYPE),String(SCIM_DEFAULT_WNN_SERVERTYPE));
+    
+    if (wnn) delete(wnn);
+    wnn = new WnnConversion(_scim_config);
 
+    
     defaultPreEditor = _scim_config->read(String(SCIM_CONFIG_WNN_DEFAULT_PREEDITOR),String(SCIM_DEFAULT_WNN_DEFAULT_PREEDITOR));
     auto_conversion = _scim_config->read(String(SCIM_CONFIG_WNN_AUTO_CONVERSION),SCIM_DEFAULT_WNN_AUTO_CONVERSION);;
 
@@ -313,7 +307,7 @@ void WnnInstance::init()
     changePreEditor(defaultPreEditor);
 
     // ǰ³Ƥ
-    wnn.wnnConnect(String("scim-wnn"),host,rc,sType,0);
+    wnn->connect();
 
 }
 
@@ -385,11 +379,11 @@ void WnnInstance::updatePreEditor()
             autoConversion();
         else {
             show_preedit_string();
-            update_preedit_string(m_preeditor->getText());
+            update_preedit_string(m_preeditor->getText(),m_preeditor->getAttributeList());
             update_preedit_caret(m_preeditor->getPos());
         }
-        if ((!m_conversion) && yosoku && wnn.isConnected() && (sType == Wnn7) && (!auto_conversion)) {
-            m_convList = wnn.getYosokuList(m_preeditor->getText());
+        if ((!m_conversion) && yosoku && wnn->isConnected() && (sType == "Wnn7") && (!auto_conversion)) {
+            m_convList = wnn->getYosokuList(m_preeditor->getText());
             if (m_convList.count) {
                 m_lookup_table.clear();
                 for(unsigned int i = 0;i < m_convList.count;i ++) {
@@ -419,8 +413,8 @@ void WnnInstance::updatePreEditor()
  */
 void WnnInstance::updateConversion()
 {
-    update_preedit_string(wnn.getText(),wnn.getAttributeList());
-    update_preedit_caret(wnn.getCaretPos());
+    update_preedit_string(wnn->getText(),wnn->getAttributeList());
+    update_preedit_caret(wnn->getCaretPos());
     if (m_lookup) {
         m_lookup_table.set_cursor_pos(m_convList.pos);
         update_lookup_table(m_lookup_table);
@@ -466,8 +460,8 @@ bool WnnInstance::process_preedit_key_event(const KeyEvent &key)
         } else
         if (k_commit.comp(key)) {
             if (auto_conversion) {
-                commit_string(wnn.getText());
-                wnn.reset();
+                commit_string(wnn->getText());
+                wnn->reset();
             } else commit_string(m_preeditor->getText(true));
             m_preeditor->reset();
             updatePreEditor();
@@ -542,8 +536,8 @@ bool WnnInstance::process_preedit_key_event(const KeyEvent &key)
         // preeditorǽǤʤäϤϤcommitƥץꥱ֤٤
         if (m_preeditor->getTextLength()) {
             if (auto_conversion) {
-                commit_string(wnn.getText());
-                wnn.reset();
+                commit_string(wnn->getText());
+                wnn->reset();
             } else commit_string(m_preeditor->getText(true));
         }
         m_preeditor->reset();
@@ -589,10 +583,10 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
         }
     } else
     if (k_commit.comp(key)) {
-        commit_string(wnn.getText());
-        wnn.updateFrequency();
+        commit_string(wnn->getText());
+        wnn->updateFrequency();
         m_preeditor->reset();
-        wnn.reset();
+        wnn->reset();
         m_conversion = false;
         updatePreEditor();
         m_lookup = false;
@@ -600,7 +594,7 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
         return(true);
     } else
     if (k_cancel.comp(key) || k_backspace.comp(key)) {
-        wnn.reset();
+        wnn->reset();
         m_conversion = false;
         m_lookup = false;
         alp_count = 0;
@@ -613,15 +607,15 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
         else if (m_convList.pos < 0) m_convList.pos = m_convList.count - 1;
         alp_count ++;
 
-        wnn.select(m_convList.pos);
+        wnn->select(m_convList.pos);
         updateConversion();
         return(true);
     } else
     if (k_conversion_expand.comp(key) || k_conversion_shrink.comp(key)) {
         bool r;
-        k_conversion_shrink.comp(key) ? r = wnn.resizeRegion(-1) : r = wnn.resizeRegion(1);
+        k_conversion_shrink.comp(key) ? r = wnn->resizeRegion(-1) : r = wnn->resizeRegion(1);
         if (!r) return(true);
-        m_convList = wnn.getConversionList();
+        m_convList = wnn->getResultList();
         if (alp == -1) {
             startLookup();
         } else m_lookup = false;
@@ -629,16 +623,16 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
         alp_count = 1;
         return(true);
     } else
-    if (k_conversion_rensou.comp(key) && ((sType == Wnn7) || (sType == Wnn8)) ) {
-        m_convList = wnn.getConversionList(wnn.getPos(),RENSOU);
+    if (k_conversion_rensou.comp(key) && ((sType == "Wnn7") || (sType == "Wnn8")) ) {
+        m_convList = wnn->getResultList(wnn->getPos(),RENSOU);
         if (m_convList.count == 0) return(true);
         startLookup();
         updateConversion();
         alp_count = 1;
         return(true);
     } else
-    if (k_conversion_ikeiji.comp(key) && ((sType == Wnn7) || (sType == Wnn8)) ) {
-        m_convList = wnn.getConversionList(wnn.getPos(),IKEIJI);
+    if (k_conversion_ikeiji.comp(key) && ((sType == "Wnn7") || (sType == "Wnn8")) ) {
+        m_convList = wnn->getResultList(wnn->getPos(),IKEIJI);
         if (m_convList.count == 0) return(true);
         startLookup();
         updateConversion();
@@ -646,8 +640,8 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
         return(true);
     } else
     if (k_conversion_forward.comp(key) || k_conversion_backward.comp(key)) {
-        k_conversion_backward.comp(key) ? wnn.setPos(wnn.getPos() - 1) : wnn.setPos(wnn.getPos() + 1);
-        m_convList = wnn.getConversionList();
+        k_conversion_backward.comp(key) ? wnn->setPos(wnn->getPos() - 1) : wnn->setPos(wnn->getPos() + 1);
+        m_convList = wnn->getResultList();
         if (alp == -1) {
             startLookup();
         } else m_lookup = false;
@@ -661,7 +655,7 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
         for(unsigned int i = 0;i < m_convList.count;i ++) {
             if (res == m_convList.kouho[i]) {
                 m_convList.pos = i;
-                wnn.select(m_convList.pos);
+                wnn->select(m_convList.pos);
                 updateConversion();
                 break;
             }
@@ -683,19 +677,19 @@ bool WnnInstance::process_conversion_key_event(const KeyEvent &key)
                 if (numkey) {
                     if (m_lookup_table.get_current_page_size() < numc) return(true);
                     m_convList.pos = numc + m_lookup_table.get_current_page_start();
-                    wnn.select(m_convList.pos);
-                    wnn.setPos(wnn.getPos() + 1);
-                    m_convList = wnn.getConversionList();
+                    wnn->select(m_convList.pos);
+                    wnn->setPos(wnn->getPos() + 1);
+                    m_convList = wnn->getResultList();
                     updateConversion();
                     startLookup();
                     return(true);
                 }
             }
 
-        commit_string(wnn.getText());
-        wnn.updateFrequency();
+        commit_string(wnn->getText());
+        wnn->updateFrequency();
         m_preeditor->reset();
-        wnn.reset();
+        wnn->reset();
         m_conversion = false;
         m_lookup = false;
         alp_count = 0;
@@ -788,10 +782,10 @@ void WnnInstance::select_candidate (unsigned int item)
 
     int p = m_lookup_table.get_current_page_start() + item;
     m_convList.pos = p;
-    wnn.select(m_convList.pos);
+    wnn->select(m_convList.pos);
     if (m_convList.kType != YOSOKU) {
-        update_preedit_string(wnn.getText(),wnn.getAttributeList());
-        update_preedit_caret(wnn.getCaretPos());
+        update_preedit_string(wnn->getText(),wnn->getAttributeList());
+        update_preedit_caret(wnn->getCaretPos());
     } else {
         update_preedit_string(m_convList.kouho.at(m_convList.pos));
         update_preedit_caret(0);
@@ -818,9 +812,9 @@ void WnnInstance::lookup_table_page_up ()
     int p = m_convList.pos - m_lookup_table.get_current_page_size();
     if (p < 0) p = 0;
     m_convList.pos = p;
-    wnn.select(m_convList.pos);
-    update_preedit_string(wnn.getText(),wnn.getAttributeList());
-    update_preedit_caret(wnn.getCaretPos());
+    wnn->select(m_convList.pos);
+    update_preedit_string(wnn->getText(),wnn->getAttributeList());
+    update_preedit_caret(wnn->getCaretPos());
     m_lookup_table.set_cursor_pos(m_convList.pos);
     update_lookup_table(m_lookup_table);
 }
@@ -835,9 +829,9 @@ void WnnInstance::lookup_table_page_down ()
     int p = m_convList.pos + m_lookup_table.get_current_page_size();
     if (p >= m_convList.count) p = m_convList.count - 1;
     m_convList.pos = p;
-    wnn.select(m_convList.pos);
-    update_preedit_string(wnn.getText(),wnn.getAttributeList());
-    update_preedit_caret(wnn.getCaretPos());
+    wnn->select(m_convList.pos);
+    update_preedit_string(wnn->getText(),wnn->getAttributeList());
+    update_preedit_caret(wnn->getCaretPos());
     m_lookup_table.set_cursor_pos(m_convList.pos);
     update_lookup_table(m_lookup_table);
 }
@@ -848,10 +842,10 @@ void WnnInstance::reset ()
     alp_count = 0;
     m_conversion = false;
     m_lookup = false;
-    wnn.reset();
+    wnn->reset();
     m_preeditor->reset();
-    //if (wnn.isConnected()) wnn.wnnDisconnect();
-    //wnn.wnnConnect(String("scim-wnn"),host,rc,sType,0);
+    //if (wnn->isConnected()) wnn->wnnDisconnect();
+    //wnn->wnnConnect(String("scim-wnn"),host,rc,sType,0);
     //updatePreEditor();
 }
 
@@ -864,9 +858,9 @@ void WnnInstance::focus_in ()
 void WnnInstance::focus_out ()
 {
     if (m_conversion) {
-        commit_string(wnn.getText());
-        wnn.updateFrequency();
-        wnn.reset();
+        commit_string(wnn->getText());
+        wnn->updateFrequency();
+        wnn->reset();
         m_conversion = false;
         m_lookup = false;
         alp_count = 0;
@@ -907,29 +901,29 @@ void WnnInstance::startConversion(WideString s)
     hide_lookup_table();
 
     hide_aux_string();
-    if (!wnn.isConnected()) {
-        if (!wnn.wnnConnect(String("scim-wnn"),host,rc,sType,0)) {
+    if (!wnn->isConnected()) {
+        if (!wnn->connect()) {
             update_aux_string(utf8_mbstowcs(String(_("could not connect to jserver."))));
             show_aux_string();
             return;
         }
     }
 
-    wnn.setYomiText(s);
-    if (wnn.ren_conversion() == -1) {
+    wnn->setYomiText(s);
+    if (wnn->ren_conversion() == -1) {
         update_aux_string(utf8_mbstowcs(String(_("could not connect to jserver."))));
         show_aux_string();
         return;
     }
     m_convList.kouho.clear();
-    m_convList = wnn.getConversionList();
+    m_convList = wnn->getResultList();
     m_conversion = true;
 
     alp_count = 1;
 
     show_preedit_string();
-    update_preedit_string(wnn.getText(),wnn.getAttributeList());
-    update_preedit_caret(wnn.getCaretPos());
+    update_preedit_string(wnn->getText(),wnn->getAttributeList());
+    update_preedit_caret(wnn->getCaretPos());
     if (alp == -1) {
         startLookup();
     }
@@ -942,38 +936,38 @@ void WnnInstance::startConversion(WideString s)
  */
 void WnnInstance::autoConversion()
 {
-    if (!wnn.isConnected()) {
-        if (!wnn.wnnConnect(String("scim-wnn"),host,rc,sType,0)) {
+    if (!wnn->isConnected()) {
+        if (!wnn->connect()) {
             update_aux_string(utf8_mbstowcs(String(_("could not connect to jserver."))));
             show_aux_string();
             show_preedit_string();
-            update_preedit_string(m_preeditor->getText());
+            update_preedit_string(m_preeditor->getText(),m_preeditor->getAttributeList());
             update_preedit_caret(m_preeditor->getPos());
             return;
         }
     }
 
-    wnn.reset();
-    wnn.setYomiText(m_preeditor->getText(true));
-    if (wnn.ren_conversion() == -1) {
+    wnn->reset();
+    wnn->setYomiText(m_preeditor->getText(true));
+    if (wnn->ren_conversion() == -1) {
         update_aux_string(utf8_mbstowcs(String(_("could not connect to jserver."))));
         show_aux_string();
         show_preedit_string();
-        update_preedit_string(m_preeditor->getText());
+        update_preedit_string(m_preeditor->getText(),m_preeditor->getAttributeList());
         update_preedit_caret(m_preeditor->getPos());
         return;
     }
 
     show_preedit_string();
-    update_preedit_string(wnn.getText());
-    update_preedit_caret(wnn.getText().size());
+    update_preedit_string(wnn->getText());
+    update_preedit_caret(wnn->getText().size());
 }
 
 
 /*!
-    \fn WnnInstance::createLookupTable(WnnConversionList cList)
+    \fn WnnInstance::createLookupTable(ResultList cList)
  */
-void WnnInstance::createLookupTable(WnnConversionList cList)
+void WnnInstance::createLookupTable(ResultList cList)
 {
     hide_lookup_table();
     m_lookup_table.clear();
