@@ -88,11 +88,11 @@ public:
 protected:
     CommonLookupTable m_lookup_table;
     PreEditor *m_preeditor;
-    WnnConversion wnn;
+    Convertor *wnn;
     bool m_conversion;
     bool m_yosoku;
     bool m_lookup;
-    WnnConversionList m_convList;
+    ResultList m_convList;
     PropertyList m_proplist;
     int alp;
     int alp_count;
@@ -100,18 +100,16 @@ protected:
     bool mini_status;
     bool yosoku;
     bool auto_conversion;
-    String host;
-    String rc;
-    JServerType sType;
     String defaultPreEditor;
     IConvert m_iconv;
     vector<PreEditor *> preeditors;
+    String sType;
 protected:
     bool process_preedit_key_event(const KeyEvent &key);
     bool process_conversion_key_event(const KeyEvent &key);
     bool process_yosoku_key_event(const KeyEvent &key);
     void startConversion(WideString s);
-    void createLookupTable(WnnConversionList cList);
+    void createLookupTable(ResultList cList);
     void init();
     void updatePreEditor();
     void updateProperty();
