@@ -29,6 +29,7 @@
 #include <scim.h>
 #include <scim_iconv.h>
 #include <scim_attribute.h>
+#include <convertor.h>
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -43,42 +44,42 @@ using namespace std;
 /**
 @author TAM(Teppei Tamra)
 */
-enum KouhoType { DEFAULT, IKEIJI, RENSOU, YOSOKU };
+namespace ScimWnn {
 enum JServerType { Wnn4, Wnn6, Wnn7, Wnn8 };
 
-class WnnConversionList{
-public:
-    WideString Yomi;
-    int pos;
-    int count;
-    KouhoType kType;
-    vector<WideString> kouho;
-};
+#define DEFAULT 0
+#define IKEIJI  1
+#define RENSOU  2
+#define YOSOKU  3
 
 
-class WnnConversion{
+class WnnConversion : public Convertor {
 public:
-    WnnConversion();
+    WnnConversion(ConfigPointer cfg);
 
     ~WnnConversion();
-    bool isConnected();
-    void reset();
-    void setYomiText(WideString yomi);
-    int ren_conversion();
-    WideString getText();
-    int setPos(int p);
-    int getPos();
-    WnnConversionList getConversionList(int p = -1 ,KouhoType kt = DEFAULT);
-    WnnConversionList getYosokuList(const WideString &str);
-    bool select(int p);
-    AttributeList getAttributeList();
-    bool resizeRegion(int w);
-    void updateFrequency();
-    bool wnnConnect(String name,String host,String rc,JServerType type,int timeout);
-    void wnnDisconnect();
-    int getCaretPos();
+    virtual bool isConnected();
+    virtual void reset();
+    virtual void setYomiText(WideString yomi);
+    virtual int ren_conversion();
+    virtual WideString getText();
+    virtual int setPos(int p);
+    virtual int getPos();
+    virtual ResultList getResultList(int p = -1 ,int kt = DEFAULT);
+    virtual ResultList getYosokuList(const WideString &str);
+    virtual bool select(int p);
+    virtual AttributeList getAttributeList();
+    virtual bool resizeRegion(int w);
+    virtual void updateFrequency();
+    virtual bool connect();
+    virtual void disconnect();
+    virtual int getCaretPos();
+    virtual String getName();
+
 
 protected:
+    bool wnnConnect(String name,String host,String rc,JServerType type,int timeout);
+    void wnnDisconnect();
     void wstostr(unsigned char *e,w_char *u);
     void strtows(w_char *u,unsigned char *e);
     static int wnn_message (char *s);
@@ -100,8 +101,8 @@ protected:
     vector<WideString> bunList;
     vector<WideString> yomiList;
     AttributeList attr;
-    WnnConversionList convList;
+    ResultList convList;
 
 };
-
+}
 #endif
